@@ -1,6 +1,6 @@
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # Mobius Forensic Toolkit
-# Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024 Eduardo Aguiar
+# Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Eduardo Aguiar
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -105,21 +105,21 @@ class FileFinderView(object):
         self.__widget = mobius.ui.container()
         self.__widget.show()
 
-        vbox = Gtk.VBox()
+        vbox = mobius.ui.box(mobius.ui.box.orientation_vertical)
         vbox.set_spacing(5)
-        vbox.show()
+        vbox.set_visible(True)
         self.__widget.set_content(vbox)
 
         # navigation bar
         self.__navigation_bar = NavigationBar(control)
         self.__navigation_bar.show()
-        vbox.pack_start(self.__navigation_bar.get_ui_widget(), False, True, 0)
+        vbox.add_child(self.__navigation_bar.get_ui_widget(), mobius.ui.box.fill_none)
 
         # vpaned
         self.__vpaned = Gtk.VPaned()
         self.__vpaned.set_border_width(5)
         self.__vpaned.show()
-        vbox.pack_start(self.__vpaned, True, True, 0)
+        vbox.add_child(self.__vpaned, mobius.ui.box.fill_with_widget)
 
         position = mobius.framework.get_config('file-explorer.file-finder-vpaned-position')
 
@@ -127,15 +127,15 @@ class FileFinderView(object):
             self.__vpaned.set_position(position)
 
         # search area
-        search_hbox = Gtk.HBox()
+        search_hbox = mobius.ui.box(mobius.ui.box.orientation_horizontal)
         search_hbox.set_spacing(5)
-        search_hbox.show()
-        self.__vpaned.pack1(search_hbox, True, True)
+        search_hbox.set_visible(True)
+        self.__vpaned.pack1(search_hbox.get_ui_widget(), True, True)
 
         sw = Gtk.ScrolledWindow()
         sw.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
         sw.show()
-        search_hbox.pack_start(sw, True, True, 0)
+        search_hbox.add_child(sw, mobius.ui.box.fill_with_widget)
 
         language_manager = GtkSource.LanguageManager.get_default()
         language = language_manager.get_language('python')
@@ -154,10 +154,10 @@ class FileFinderView(object):
         self.__sourceview.override_font(font)
         sw.add(self.__sourceview)
 
-        search_vbox = Gtk.VBox()
+        search_vbox = mobius.ui.box(mobius.ui.box.orientation_vertical)
         search_vbox.set_spacing(5)
-        search_vbox.show()
-        search_hbox.pack_end(search_vbox, False, False, 0)
+        search_vbox.set_visible(True)
+        search_hbox.add_child(search_vbox, mobius.ui.box.fill_none)
 
         # combobox
         datastore = Gtk.ListStore.new([str, object])
@@ -167,26 +167,26 @@ class FileFinderView(object):
         self.__filter_combobox.connect('changed', self.__on_combobox_selection_changed)
         self.__filter_combobox.set_active(0)
         self.__filter_combobox.show()
-        search_vbox.pack_start(self.__filter_combobox, True, True, 0)
+        search_vbox.add_child(self.__filter_combobox, mobius.ui.box.fill_with_widget)
 
         renderer = Gtk.CellRendererText()
         renderer.set_padding(5, 0)
         self.__filter_combobox.pack_start(renderer, True)
         self.__filter_combobox.add_attribute(renderer, 'text', 0)
 
-        image = Gtk.Image.new_from_icon_name('edit-find', Gtk.IconSize.BUTTON)
-        self.__search_button = Gtk.Button.new_with_mnemonic('_Find')
-        self.__search_button.set_image(image)
-        self.__search_button.show()
-        self.__search_button.connect('clicked', self.__on_search_button_clicked)
-        search_vbox.pack_end(self.__search_button, True, True, 0)
+        self.__search_button = mobius.ui.button()
+        self.__search_button.set_icon_by_name('edit-find')
+        self.__search_button.set_text('_Find')
+        self.__search_button.set_visible(True)
+        self.__search_button.set_callback('clicked', self.__on_search_button_clicked)
+        search_vbox.add_child(self.__search_button, mobius.ui.box.fill_with_widget)
 
         # view
         self.__listview = self.__mediator.call('ui.new-widget', 'tableview')
         self.__listview.set_control(self, 'listview')
         self.__listview.set_multiple_selection(True)
         self.__listview.set_report_id('filelist')
-        self.__listview.set_report_app('%s v%s' % (EXTENSION_NAME, EXTENSION_VERSION))
+        self.__listview.set_report_app(f'{EXTENSION_NAME} v{EXTENSION_VERSION}')
 
         column = self.__listview.add_column('icon', 'Icon', column_type='icon')
 
@@ -201,19 +201,19 @@ class FileFinderView(object):
 
         path = self.__mediator.call('extension.get-resource-path', EXTENSION_ID, 'file.svg')
         image = mobius.ui.new_icon_by_path(path, mobius.ui.icon.size_toolbar)
-        icon = image.get_widget().get_ui_widget().get_pixbuf()
+        icon = image.get_ui_widget().get_pixbuf()
         self.__listview.set_icon('file', icon)
 
         path = self.__mediator.call('extension.get-resource-path', EXTENSION_ID, 'folder.svg')
         image = mobius.ui.new_icon_by_path(path, mobius.ui.icon.size_toolbar)
-        icon = image.get_widget().get_ui_widget().get_pixbuf()
+        icon = image.get_ui_widget().get_pixbuf()
         self.__listview.set_icon('folder', icon)
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-    # @brief get ui widget
+    # @brief Get ui widget
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
     def get_ui_widget(self):
-        return self.__widget.get_widget().get_ui_widget()
+        return self.__widget.get_ui_widget()
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
     # @brief Save current state
@@ -303,7 +303,7 @@ class FileFinderView(object):
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
     # @brief Handle search button clicked event
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-    def __on_search_button_clicked(self, widget, *args):
+    def __on_search_button_clicked(self):
         try:
 
             # set expression for adhoc filter
