@@ -3,7 +3,7 @@
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -20,15 +20,45 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 #include <memory>
 
-namespace mobius
-{
-namespace database
+namespace mobius::database
 {
 class database;
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief nested transaction control class
-//! \author Eduardo Aguiar
+// @brief Nested transaction control class
+// @author Eduardo Aguiar
+//
+// This class is implemented with the following features:
+//
+// 1. Transactions can be nested:
+//    auto transaction1 = db.new_transaction ();
+//    db.execute (cmd1);
+//    ...
+//    auto transaction2 = db.new_transaction ();
+//    db.execute (cmd2);
+//    transaction2.commit (); // does not commit. Only ends transaction2
+//
+//    db.execute (cmd3);
+//    transaction1.commit (); // It commits cmd1, cmd2 and cmd3
+//
+// 2. Consecutive calls to commit or rollback for the same transaction are ignored:
+//
+//    auto transaction = db.transaction ();
+//    db.execute (cmd1);
+//
+//    db.commit ();
+//
+//    db.rollback ();  // ignored
+//    db.commit ();    // ignored
+//
+// 3. Non-commited transactions are rolled-back when transaction is destroyed:
+//
+//    {
+//      auto transaction = db.transaction ();
+//      db.execute (cmd1);
+//
+//      // transaction is rolled-back
+//    }
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 class transaction
 {
@@ -36,7 +66,7 @@ public:
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   // constructors
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  explicit transaction (database, bool);
+  explicit transaction (const database&, bool);
   transaction (const transaction&) noexcept = default;
   transaction (transaction&&) noexcept = default;
 
@@ -53,11 +83,15 @@ public:
   void rollback ();
 
 private:
-  struct impl;
+  // @brief Forward declaration
+  class impl;
+
+  // @brief Pointer to implementation class
   std::shared_ptr <impl> impl_;
 };
 
-} // namespace database
-} // namespace mobius
+} // namespace mobius::database
 
 #endif
+
+
