@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -30,12 +30,10 @@
 #include "smb/file_impl.h"
 #endif
 
-namespace mobius
-{
-namespace io
+namespace mobius::io
 {
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Construct object
+// @brief Construct object
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 file::file ()
 {
@@ -43,34 +41,17 @@ file::file ()
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Construct object
-//! \param impl Implementation object
+// @brief Construct object
+// @param impl Implementation object
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-file::file (std::shared_ptr <file_impl_base> impl)
+file::file (const std::shared_ptr <file_impl_base>& impl)
   : impl_ (impl)
 {
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Get path
-//! \return Path
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-std::string
-file::get_path () const
-{
-  std::string path;
-
-  auto data = impl_->get_metadata ("path");
-
-  if (data.is_string ())
-    path = static_cast <std::string> (data);
-
-  return path;
-}
-
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Copy file
-//! \param f File object (destination)
+// @brief Copy file
+// @param f File object (destination)
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 void
 file::copy (file f) const
@@ -80,7 +61,7 @@ file::copy (file f) const
 
   std::uint64_t BLOCK_SIZE = 65536;
   auto size = get_size ();
-  
+
   while (size > 0)
     {
       auto data = reader.read (std::min (BLOCK_SIZE, size));
@@ -90,8 +71,8 @@ file::copy (file f) const
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Copy file to folder
-//! \param folder_out Folder object (dest)
+// @brief Copy file to folder
+// @param folder_out Folder object (dest)
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 void
 file::copy (folder folder_out) const
@@ -101,8 +82,8 @@ file::copy (folder folder_out) const
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Move file
-//! \param f Destination file
+// @brief Move file
+// @param f Destination file
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 void
 file::move (file f)
@@ -117,8 +98,8 @@ file::move (file f)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Move file to folder
-//! \param folder_out Folder object (dest)
+// @brief Move file to folder
+// @param folder_out Folder object (dest)
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 void
 file::move (folder folder_out)
@@ -128,8 +109,8 @@ file::move (folder folder_out)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Get file extension
-//! \return File extension
+// @brief Get file extension
+// @return File extension
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 std::string
 file::get_extension () const
@@ -140,19 +121,19 @@ file::get_extension () const
 
   if (pos != std::string::npos && pos != 0)
     extension = filename.substr (pos + 1);
-  
+
   return extension;
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Get parent folder
-//! \return Parent folder
+// @brief Get parent folder
+// @return Parent folder
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 folder
 file::get_parent () const
 {
   auto parent = folder (impl_->get_parent ());
-  
+
   if (parent)
     {
       mobius::io::path path (get_path ());
@@ -163,9 +144,9 @@ file::get_parent () const
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Create new sibling file object by name
-//! \param name Sibling file name
-//! \return Sibling file object
+// @brief Create new sibling file object by name
+// @param name Sibling file name
+// @return Sibling file object
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 file
 file::new_sibling_by_name (const std::string& name) const
@@ -176,9 +157,9 @@ file::new_sibling_by_name (const std::string& name) const
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Create new sibling file object by extension
-//! \param ext Sibling extension
-//! \return Sibling file object
+// @brief Create new sibling file object by extension
+// @param ext Sibling extension
+// @return Sibling file object
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 file
 file::new_sibling_by_extension (const std::string& ext) const
@@ -198,14 +179,14 @@ file::new_sibling_by_extension (const std::string& ext) const
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Get streams
-//! \return Streams
+// @brief Get streams
+// @return Streams
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 std::vector <stream>
 file::get_streams () const
 {
   auto impl_streams = impl_->get_streams ();
-  
+
   std::vector <stream> streams (impl_streams.size ());
 
   std::transform (impl_streams.begin (),
@@ -213,14 +194,14 @@ file::get_streams () const
                   streams.begin (),
                   [](const auto& s){ return stream (s); }
                  );
-  
+
   return streams;
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Create file by path
-//! \param path file path
-//! \return file object
+// @brief Create file by path
+// @param path file path
+// @return file object
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 file
 new_file_by_path (const std::string& path)
@@ -229,9 +210,9 @@ new_file_by_path (const std::string& path)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Create file by URI
-//! \param url file URL
-//! \return file object
+// @brief Create file by URI
+// @param url file URL
+// @return file object
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 file
 new_file_by_url (const std::string& url)
@@ -239,7 +220,7 @@ new_file_by_url (const std::string& url)
   mobius::io::uri u (url);
 
   if (u.get_scheme () == "file")
-    return new_file_by_path (u.get_path ());
+    return new_file_by_path (u.get_path ("utf-8"));
 
 #ifdef HAVE_SMB_SUPPORT
   else if (u.get_scheme () == "smb")
@@ -247,8 +228,9 @@ new_file_by_url (const std::string& url)
 #endif
 
   else
-    throw std::invalid_argument (MOBIUS_EXCEPTION_MSG ("unknown file scheme"));
+    throw std::invalid_argument (MOBIUS_EXCEPTION_MSG ("unhandled file scheme"));
 }
 
-} // namespace io
-} // namespace mobius
+} // namespace mobius::io
+
+
