@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -25,12 +25,12 @@
 
 namespace mobius::os::win::registry
 {
-namespace               // local namespace
+namespace
 {
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief retrieve pssp cryptographic keys from SID key
-//! \param sid_key SID key
-//! \return PSSP key collection
+// @brief retrieve pssp cryptographic keys from SID key
+// @param sid_key SID key
+// @return PSSP key collection
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 pssp_data2
 get_data2 (registry_key sid_key)
@@ -94,9 +94,9 @@ get_data2 (registry_key sid_key)
 } // local namespace
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief set Protected Storage System Provider (PSSP) keys
-//! \see https://msdn.microsoft.com/library/bb432403.aspx
-//! \param root registry root key
+// @brief set Protected Storage System Provider (PSSP) keys
+// @see https://msdn.microsoft.com/library/bb432403.aspx
+// @param root registry root key
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 void
 registry_set_pssp_keys (registry_key root)
@@ -120,3 +120,5 @@ registry_set_pssp_keys (registry_key root)
 }
 
 } // namespace mobius::os::win::registry
+
+
