@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -17,19 +17,47 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief  C++ API module wrapper
-//! \author Eduardo Aguiar
+// @brief  C++ API module wrapper
+// @author Eduardo Aguiar
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 #include <pymobius.h>
 #include "api_dataholder.h"
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief api.dataholder: prototypes
+// @brief tp_dir implementation
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-static void api_dataholder_tp_dealloc (api_dataholder_o *);
+static PyObject *
+tp_dir (api_dataholder_o *self, PyObject *)
+{
+  return PyDict_Keys (self->dict);
+}
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief api.dataholder: type structure
+// @brief Methods structure
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyMethodDef tp_methods[] =
+{
+  {
+    (char *) "__dir__",
+    (PyCFunction) tp_dir,
+    METH_VARARGS,
+    "dir function implementation"
+  },
+  {NULL, NULL, 0, NULL} // sentinel
+};
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+// @brief api.dataholder: tp_dealloc
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static void
+api_dataholder_tp_dealloc (api_dataholder_o *self)
+{
+  Py_DECREF (self->dict);
+  Py_TYPE (self)->tp_free ((PyObject*) self);
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+// @brief api.dataholder: type structure
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 PyTypeObject api_dataholder_t =
 {
@@ -60,7 +88,7 @@ PyTypeObject api_dataholder_t =
   0,                                          		// tp_weaklistoffset
   0,                                          		// tp_iter
   0,                                          		// tp_iternext
-  0,                                          		// tp_methods
+  tp_methods,                                  		// tp_methods
   0,                                          		// tp_members
   0,                                         		// tp_getset
   0,                                          		// tp_base
@@ -80,20 +108,11 @@ PyTypeObject api_dataholder_t =
   0,                                       		// tp_weaklist
   0,                                       		// tp_del
   0,                                       		// tp_version_tag
+  0,                                       		// tp_finalize
 };
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief api.dataholder: tp_dealloc
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-static void
-api_dataholder_tp_dealloc (api_dataholder_o *self)
-{
-  Py_DECREF (self->dict);
-  self->ob_type->tp_free ((PyObject*) self);
-}
-
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief api.dataholder: create new object
+// @brief api.dataholder: create new object
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 api_dataholder_o *
 api_dataholder_new ()
@@ -107,57 +126,59 @@ api_dataholder_new ()
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief set attribute
-//! \param obj object
-//! \param name name
-//! \param value value
+// @brief set attribute
+// @param obj object
+// @param name name
+// @param value value
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 void
 api_dataholder_setattr (api_dataholder_o *obj, const std::string& name, const std::string& value)
 {
   PyObject_GenericSetAttr ((PyObject *) obj,
-                           PyString2_from_std_string (name),
-                           PyString2_from_std_string (value));
+                           mobius::py::pystring_from_std_string (name),
+                           mobius::py::pystring_from_std_string (value));
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief set attribute
-//! \param obj object
-//! \param name name
-//! \param value value
+// @brief set attribute
+// @param obj object
+// @param name name
+// @param value value
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 void
 api_dataholder_setattr (api_dataholder_o *obj, const std::string& name, std::int64_t value)
 {
   PyObject_GenericSetAttr ((PyObject *) obj,
-                           PyString2_from_std_string (name),
+                           mobius::py::pystring_from_std_string (name),
                            mobius::py::pylong_from_std_int64_t (value));
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief set attribute
-//! \param obj object
-//! \param name name
-//! \param value value
+// @brief set attribute
+// @param obj object
+// @param name name
+// @param value value
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 void
 api_dataholder_setattr (api_dataholder_o *obj, const std::string& name, const mobius::datetime::datetime& value)
 {
   PyObject_GenericSetAttr ((PyObject *) obj,
-                           PyString2_from_std_string (name),
+                           mobius::py::pystring_from_std_string (name),
                            mobius::py::pydatetime_from_datetime (value));
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief set attribute
-//! \param obj object
-//! \param name name
-//! \param value value
+// @brief set attribute
+// @param obj object
+// @param name name
+// @param value value
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 void
 api_dataholder_setattr (api_dataholder_o *obj, const std::string& name, PyObject *value)
 {
   PyObject_GenericSetAttr ((PyObject *) obj,
-                           PyString2_from_std_string (name),
+                           mobius::py::pystring_from_std_string (name),
                            value);
 }
+
+
