@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -17,53 +17,55 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief  C++ API mobius.core module wrapper
-//! \author Eduardo Aguiar
+// @brief  C++ API mobius.core module wrapper
+// @author Eduardo Aguiar
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 #include "module.h"
 #include <pymobius.h>
 #include "application.h"
-#include "attribute.h"
-#include "category.h"
-#include "category_manager.h"
 #include "extension.h"
 #include "log.h"
+#include "resource.h"
+#include "thread_guard.h"
+#include "decoder/module.h"
+#include "file_decoder/module.h"
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Functions prototypes
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 PyObject* func_logf (PyObject *, PyObject *);
 PyObject* func_set_logfile_path (PyObject *, PyObject *);
+PyObject* func_add_resource (PyObject *, PyObject *);
+PyObject* func_remove_resource (PyObject *, PyObject *);
+PyObject* func_has_resource (PyObject *, PyObject *);
+PyObject* func_get_resource (PyObject *, PyObject *);
+PyObject* func_get_resources (PyObject *, PyObject *);
+PyObject* func_get_resource_value (PyObject *, PyObject *);
+PyObject* func_subscribe (PyObject *, PyObject *);
+PyObject* func_unsubscribe (PyObject *, PyObject *);
 
 namespace
 {
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Module methods
+// @brief Module methods
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyMethodDef module_methods[] =
 {
-  {
-    "logf",
-    func_logf,
-    METH_VARARGS,
-    "Log event"
-  },
-  {
-    "set_logfile_path",
-    func_set_logfile_path,
-    METH_VARARGS,
-    "Set log file path"
-  },
-  {
-    NULL,
-    NULL,
-    0,
-    NULL
-  } // sentinel
+  {"add_resource", func_add_resource, METH_VARARGS, "Add resource"},
+  {"get_resource", func_get_resource, METH_VARARGS, "Get resource"},
+  {"get_resource_value", func_get_resource_value, METH_VARARGS, "Get resource value"},
+  {"get_resources", func_get_resources, METH_VARARGS, "Get resources"},
+  {"has_resource", func_has_resource, METH_VARARGS, "Check if resource exists"},
+  {"logf", func_logf, METH_VARARGS, "Log event"},
+  {"remove_resource", func_remove_resource, METH_VARARGS, "Remove resource"},
+  {"set_logfile_path", func_set_logfile_path, METH_VARARGS, "Set log file path"},
+  {"subscribe", func_subscribe, METH_VARARGS, "Subscribe to event"},
+  {"unsubscribe", func_unsubscribe, METH_VARARGS, "Unsubscribe from event"},
+  {nullptr, nullptr, 0, nullptr}, // sentinel
 };
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Module definition structure
+// @brief Module definition structure
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyModuleDef module_def =
 {
@@ -81,7 +83,7 @@ static PyModuleDef module_def =
 } // namespace
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Module initialization function
+// @brief Module initialization function
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 mobius::py::pymodule
 new_core_module ()
@@ -91,15 +93,16 @@ new_core_module ()
 
   // Add types
   module.add_type ("application", &core_application_t);
-  module.add_type ("attribute", &core_attribute_t);
-  module.add_type ("category_manager", &core_category_manager_t);
-  module.add_type ("category", &core_category_t);
   module.add_type ("extension", &core_extension_t);
   module.add_type ("log", &core_log_t);
+  module.add_type ("resource", &core_resource_t);
+  module.add_type ("thread_guard", new_core_thread_guard_type ());
 
   // Build submodules
-  //module.add_submodule ("xxx", new_xxx_submodule ());
+  module.add_submodule ("file_decoder", new_core_file_decoder_module ());
 
   // Return module
   return module;
 }
+
+
