@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -18,7 +18,7 @@
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \file C++ API <i>mobius.crypt</i> module wrapper
-//! \author Eduardo Aguiar
+// @author Eduardo Aguiar
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 #include "module.h"
 #include <pymobius.h>
@@ -27,16 +27,25 @@
 #include "hmac.h"
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Function prototypes
+// @brief Function prototypes
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 PyObject * func_hash_digest (PyObject *, PyObject *);
+PyObject * func_new_cipher_cbc (PyObject *, PyObject *);
+PyObject * func_new_cipher_cbc_cts (PyObject *, PyObject *);
+PyObject * func_new_cipher_ctr (PyObject *, PyObject *);
+PyObject * func_new_cipher_ecb (PyObject *, PyObject *);
+PyObject * func_new_cipher_gcm (PyObject *, PyObject *);
+PyObject * func_new_cipher_ige (PyObject *, PyObject *);
+PyObject * func_new_cipher_ofb (PyObject *, PyObject *);
+PyObject * func_new_cipher_stream (PyObject *, PyObject *);
 PyObject * func_pbkdf1 (PyObject *, PyObject *);
 PyObject * func_pbkdf2_hmac (PyObject *, PyObject *);
+PyObject * func_rot13 (PyObject *, PyObject *);
 
 namespace
 {
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Module methods
+// @brief Module methods
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyMethodDef module_methods[] =
 {
@@ -46,6 +55,54 @@ static PyMethodDef module_methods[] =
     METH_VARARGS,
     "Generate hash digest for data"
   },
+  {
+    "new_cipher_cbc",
+    func_new_cipher_cbc,
+    METH_VARARGS,
+    "Create new cipher object with CBC mode"
+  },
+  {
+    "new_cipher_cbc_cts",
+    func_new_cipher_cbc_cts,
+    METH_VARARGS,
+    "Create new cipher object with CBC/CTS mode"
+  },
+  {
+    "new_cipher_ctr",
+    func_new_cipher_ctr,
+    METH_VARARGS,
+    "Create new cipher object with CTR mode"
+  },
+  {
+    "new_cipher_ecb",
+    func_new_cipher_ecb,
+    METH_VARARGS,
+    "Create new cipher object with ECB mode"
+  },
+  {
+    "new_cipher_gcm",
+    func_new_cipher_gcm,
+    METH_VARARGS,
+    "Create new cipher object with GCM mode"
+  },
+  {
+    "new_cipher_ige",
+    func_new_cipher_ige,
+    METH_VARARGS,
+    "Create new cipher object with IGE mode"
+  },
+  {
+    "new_cipher_ofb",
+    func_new_cipher_ofb,
+    METH_VARARGS,
+    "Create new cipher object with OFB mode"
+  },
+  {
+    "new_cipher_stream",
+    func_new_cipher_stream,
+    METH_VARARGS,
+    "Create new stream cipher object"
+  },
   {
     "pbkdf1",
     func_pbkdf1,
@@ -58,6 +115,12 @@ static PyMethodDef module_methods[] =
     METH_VARARGS,
     "Generate derived key using PBKDF2_HMAC"
   },
+  {
+    "rot13",
+    func_rot13,
+    METH_VARARGS,
+    "Encode/decode data with ROT-13 algorithm"
+  },
   {
     NULL,
     NULL,
@@ -67,7 +130,7 @@ static PyMethodDef module_methods[] =
 };
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Module definition structure
+// @brief Module definition structure
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyModuleDef module_def =
 {
@@ -85,7 +148,7 @@ static PyModuleDef module_def =
 } // namespace
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Create mobius.crypt module
+// @brief Create mobius.crypt module
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 mobius::py::pymodule
 new_crypt_module ()
@@ -101,3 +164,5 @@ new_crypt_module ()
   // Return module
   return module;
 }
+
+
