@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -17,8 +17,8 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief  C++ API module wrapper
-//! \author Eduardo Aguiar
+// @brief  C++ API module wrapper
+// @author Eduardo Aguiar
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 #include <Python.h>
 #include "module.h"
@@ -31,15 +31,15 @@
 #include "core/module.h"
 #include "crypt/module.h"
 #include "database/module.h"
+#include "datasource/module.h"
 #include "datetime/module.h"
 #include "decoder/module.h"
-#include "disk/module.h"
 #include "encoder/module.h"
+#include "framework/module.h"
 #include "kff/module.h"
 #include "io/module.h"
 #include "model/module.h"
 #include "os/module.h"
-#include "partition/module.h"
 #include "pod/module.h"
 #include "system/module.h"
 #include "turing/module.h"
@@ -49,7 +49,7 @@
 namespace
 {
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Module definition structure
+// @brief Module definition structure
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyModuleDef module_def =
 {
@@ -67,7 +67,7 @@ static PyModuleDef module_def =
 } // namespace
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Module initialisation function
+// @brief Module initialisation function
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 PyMODINIT_FUNC
 PyInit_mobius (void)
@@ -87,15 +87,15 @@ PyInit_mobius (void)
       module.add_submodule ("core", new_core_module ());
       module.add_submodule ("crypt", new_crypt_module ());
       module.add_submodule ("database", new_database_module ());
+      module.add_submodule ("datasource", new_datasource_module ());
       module.add_submodule ("datetime", new_datetime_module ());
       module.add_submodule ("decoder", new_decoder_module ());
-      module.add_submodule ("disk", new_disk_module ());
       module.add_submodule ("encoder", new_encoder_module ());
+      module.add_submodule ("framework", new_framework_module ());
       module.add_submodule ("kff", new_kff_module ());
       module.add_submodule ("io", new_io_module ());
       module.add_submodule ("model", new_model_module ());
       module.add_submodule ("os", new_os_module ());
-      module.add_submodule ("partition", new_partition_module ());
       module.add_submodule ("pod", new_pod_module ());
       module.add_submodule ("system", new_system_module ());
       module.add_submodule ("turing", new_turing_module ());
@@ -120,12 +120,10 @@ PyInit_mobius (void)
 // to this file only. These functions are declared into "pymobius.h"
 // header file and can be used throughout the api_xxx.cc source files.
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-namespace mobius
-{
-namespace py
+namespace mobius::py
 {
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Check if object is PyDateTime
+// @brief Check if object is PyDateTime
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 bool
 pydatetime_check (PyObject *obj)
@@ -134,7 +132,7 @@ pydatetime_check (PyObject *obj)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Create PyDateTime from mobius::datetime::datetime
+// @brief Create PyDateTime from mobius::datetime::datetime
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 PyObject *
 pydatetime_from_datetime (const mobius::datetime::datetime& dt)
@@ -162,7 +160,7 @@ pydatetime_from_datetime (const mobius::datetime::datetime& dt)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Create mobius::datetime::datetime from PyDateTime
+// @brief Create mobius::datetime::datetime from PyDateTime
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 mobius::datetime::datetime
 pydatetime_as_datetime (PyObject *obj)
@@ -181,5 +179,6 @@ pydatetime_as_datetime (PyObject *obj)
   return dt;
 }
 
-} // namespace py
-} // namespace mobius
+} // namespace mobius::py
+
+
