@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -18,7 +18,7 @@
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \file message_dialog.cc C++ API <i>mobius.ui.message_dialog</i> class wrapper
-//! \author Eduardo Aguiar
+// @author Eduardo Aguiar
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 #include <pymobius.h>
 #include "message_dialog.h"
@@ -26,50 +26,9 @@
 #include <stdexcept>
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Check if value is an instance of <i>message_dialog</i>
-//! \param value Python value
-//! \return true/false
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-bool
-pymobius_ui_message_dialog_check (PyObject *value)
-{
-  return PyObject_IsInstance (value, reinterpret_cast<PyObject *> (&ui_message_dialog_t));
-}
-
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Create <i>message_dialog</i> Python object from C++ object
-//! \param obj C++ object
-//! \return New message_dialog object
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-PyObject *
-pymobius_ui_message_dialog_to_pyobject (const mobius::ui::message_dialog& obj)
-{
-  PyObject *ret = _PyObject_New (&ui_message_dialog_t);
-
-  if (ret)
-    ((ui_message_dialog_o *) ret)->obj = new mobius::ui::message_dialog (obj);
-
-  return ret;
-}
-
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Create <i>message_dialog</i> C++ object from Python object
-//! \param value Python value
-//! \return Message_dialog object
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-mobius::ui::message_dialog
-pymobius_ui_message_dialog_from_pyobject (PyObject *value)
-{
-  if (!pymobius_ui_message_dialog_check (value))
-    throw std::invalid_argument (mobius::MOBIUS_EXCEPTION_MSG ("object must be an instance of mobius.ui.message_dialog"));
-
-  return * (reinterpret_cast <ui_message_dialog_o *>(value)->obj);
-}
-
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief <i>type</i> Attribute getter
-//! \param self Object
-//! \return <i>type</i> attribute
+// @brief <i>type</i> Attribute getter
+// @param self Object
+// @return <i>type</i> attribute
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_type (ui_message_dialog_o *self)
@@ -89,9 +48,9 @@ tp_getter_type (ui_message_dialog_o *self)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief <i>title</i> Attribute getter
-//! \param self Object
-//! \return <i>title</i> attribute
+// @brief <i>title</i> Attribute getter
+// @param self Object
+// @return <i>title</i> attribute
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_title (ui_message_dialog_o *self)
@@ -111,10 +70,10 @@ tp_getter_title (ui_message_dialog_o *self)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief <i>title</i> Attribute setter
-//! \param self Object
-//! \param value New value
-//! \return 0 on success, -1 on error
+// @brief <i>title</i> Attribute setter
+// @param self Object
+// @param value New value
+// @return 0 on success, -1 on error
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static int
 tp_setter_title (ui_message_dialog_o *self, PyObject *value, void *)
@@ -150,9 +109,9 @@ tp_setter_title (ui_message_dialog_o *self, PyObject *value, void *)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief <i>text</i> Attribute getter
-//! \param self Object
-//! \return <i>text</i> attribute
+// @brief <i>text</i> Attribute getter
+// @param self Object
+// @return <i>text</i> attribute
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_text (ui_message_dialog_o *self)
@@ -172,10 +131,10 @@ tp_getter_text (ui_message_dialog_o *self)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief <i>text</i> Attribute setter
-//! \param self Object
-//! \param value New value
-//! \return 0 on success, -1 on error
+// @brief <i>text</i> Attribute setter
+// @param self Object
+// @param value New value
+// @return 0 on success, -1 on error
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static int
 tp_setter_text (ui_message_dialog_o *self, PyObject *value, void *)
@@ -211,9 +170,9 @@ tp_setter_text (ui_message_dialog_o *self, PyObject *value, void *)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief <i>informative_text</i> Attribute getter
-//! \param self Object
-//! \return <i>informative_text</i> attribute
+// @brief <i>informative_text</i> Attribute getter
+// @param self Object
+// @return <i>informative_text</i> attribute
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_informative_text (ui_message_dialog_o *self)
@@ -233,10 +192,10 @@ tp_getter_informative_text (ui_message_dialog_o *self)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief <i>informative_text</i> Attribute setter
-//! \param self Object
-//! \param value New value
-//! \return 0 on success, -1 on error
+// @brief <i>informative_text</i> Attribute setter
+// @param self Object
+// @param value New value
+// @return 0 on success, -1 on error
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static int
 tp_setter_informative_text (ui_message_dialog_o *self, PyObject *value, void *)
@@ -272,7 +231,7 @@ tp_setter_informative_text (ui_message_dialog_o *self, PyObject *value, void *)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Getters and setters structure
+// @brief Getters and setters structure
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyGetSetDef tp_getset[] =
 {
@@ -308,10 +267,10 @@ static PyGetSetDef tp_getset[] =
 };
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief <i>add_button</i> method implementation
-//! \param self Object
-//! \param args Argument list
-//! \return Response ID
+// @brief <i>add_button</i> method implementation
+// @param self Object
+// @param args Argument list
+// @return Response ID
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_f_add_button (ui_message_dialog_o *self, PyObject *args)
@@ -357,9 +316,9 @@ tp_f_add_button (ui_message_dialog_o *self, PyObject *args)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief <i>set_default_response</i> method implementation
-//! \param self Object
-//! \param args Argument list
+// @brief <i>set_default_response</i> method implementation
+// @param self Object
+// @param args Argument list
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_f_set_default_response (ui_message_dialog_o *self, PyObject *args)
@@ -393,10 +352,10 @@ tp_f_set_default_response (ui_message_dialog_o *self, PyObject *args)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief <i>run</i> method implementation
-//! \param self Object
-//! \param args Argument list
-//! \return Response ID
+// @brief <i>run</i> method implementation
+// @param self Object
+// @param args Argument list
+// @return Response ID
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_f_run (ui_message_dialog_o *self, PyObject *)
@@ -418,7 +377,7 @@ tp_f_run (ui_message_dialog_o *self, PyObject *)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Methods structure
+// @brief Methods structure
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyMethodDef tp_methods[] =
 {
@@ -444,11 +403,11 @@ static PyMethodDef tp_methods[] =
 };
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief <i>message_dialog</i> Constructor
-//! \param type Type object
-//! \param args Argument list
-//! \param kwds Keywords dict
-//! \return new <i>message_dialog</i> object
+// @brief <i>message_dialog</i> Constructor
+// @param type Type object
+// @param args Argument list
+// @param kwds Keywords dict
+// @return new <i>message_dialog</i> object
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_new (PyTypeObject *type, PyObject *args, PyObject *)
@@ -487,8 +446,8 @@ tp_new (PyTypeObject *type, PyObject *args, PyObject *)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief <i>message_dialog</i> deallocator
-//! \param self Object
+// @brief <i>message_dialog</i> deallocator
+// @param self Object
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static void
 tp_dealloc (ui_message_dialog_o *self)
@@ -498,7 +457,7 @@ tp_dealloc (ui_message_dialog_o *self)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Type structure
+// @brief Type structure
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 PyTypeObject ui_message_dialog_t =
 {
@@ -551,3 +510,82 @@ PyTypeObject ui_message_dialog_t =
   0,                                       		// tp_version_tag
   0,                                       		// tp_finalize
 };
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+// @brief Create <i>mobius.ui.message_dialog</i> type
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+mobius::py::pytypeobject
+new_ui_message_dialog_type ()
+{
+  mobius::py::pytypeobject type (&ui_message_dialog_t);
+  type.create ();
+
+  type.add_constant ("type_info", 1);
+  type.add_constant ("type_warning", 2);
+  type.add_constant ("type_question", 3);
+  type.add_constant ("type_error", 4);
+
+  type.add_constant ("button_ok", 1);
+  type.add_constant ("button_cancel", 2);
+  type.add_constant ("button_yes", 3);
+  type.add_constant ("button_no", 4);
+  type.add_constant ("button_open", 5);
+  type.add_constant ("button_save", 6);
+  type.add_constant ("button_close", 7);
+  type.add_constant ("button_discard", 8);
+  type.add_constant ("button_apply", 9);
+  type.add_constant ("button_reset", 10);
+  type.add_constant ("button_restore_defaults", 11);
+  type.add_constant ("button_help", 12);
+  type.add_constant ("button_save_all", 13);
+  type.add_constant ("button_yes_to_all", 14);
+  type.add_constant ("button_no_to_all", 15);
+  type.add_constant ("button_abort", 16);
+  type.add_constant ("button_retry", 17);
+  type.add_constant ("button_ignore", 18);
+
+  return type;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+// @brief Check if value is an instance of <i>message_dialog</i>
+// @param value Python value
+// @return true/false
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+bool
+pymobius_ui_message_dialog_check (PyObject *value)
+{
+  return PyObject_IsInstance (value, reinterpret_cast<PyObject *> (&ui_message_dialog_t));
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+// @brief Create <i>message_dialog</i> Python object from C++ object
+// @param obj C++ object
+// @return New message_dialog object
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+PyObject *
+pymobius_ui_message_dialog_to_pyobject (const mobius::ui::message_dialog& obj)
+{
+  PyObject *ret = _PyObject_New (&ui_message_dialog_t);
+
+  if (ret)
+    ((ui_message_dialog_o *) ret)->obj = new mobius::ui::message_dialog (obj);
+
+  return ret;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+// @brief Create <i>message_dialog</i> C++ object from Python object
+// @param value Python value
+// @return Message_dialog object
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+mobius::ui::message_dialog
+pymobius_ui_message_dialog_from_pyobject (PyObject *value)
+{
+  if (!pymobius_ui_message_dialog_check (value))
+    throw std::invalid_argument (mobius::MOBIUS_EXCEPTION_MSG ("object must be an instance of mobius.ui.message_dialog"));
+
+  return * (reinterpret_cast <ui_message_dialog_o *>(value)->obj);
+}
+
+
